OFlutter Name Generator
Generate names, library identifiers, and type identifiers. This package is designed to generate for the source code of package:oflutter_name, and to avoid potential conflicts with the further code generating inside the source code of package:oflutter.
Libraries inside this package will also be exported in package:oflutter/annotation.dart, package:oflutter/builder.dart, package:oflutter/compat.dart, and package:oflutter/generator.dart which is more recommended.