TypeIdentifier class

Annotations
  • @immutable

Constructors

TypeIdentifier({required String name, required Uri lib})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
lib Uri
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

$type TypeIdentifier
final

Constants

$lib → const String
$name → const String