GenerateNameLibrary class

Inheritance
Mixed-in types

Constructors

GenerateNameLibrary()
const

Properties

generators Iterable<GenerateOnAnnotationAnywhere>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(LibraryReader library, BuildStep buildStep) Future<String?>
Generates Dart code for an input Dart library.
inherited
generateComponents(LibraryReader library, BuildStep buildStep) Iterable<FutureOr<GenerateComponentResult>>
inherited
generateOnElement(Element2 element, BuildStep buildStep) Iterable<FutureOr<GenerateComponentResult>>
inherited
generateSingleLayer(Element2 element, BuildStep buildStep) Iterable<FutureOr<GenerateComponentResult>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited