TypeGenerator class
- Inheritance
-
- Object
- GenerateOnAnnotationAnywhere
- GenerateOnAnnotation
- TypeGenerator
- Mixed-in types
Constructors
- TypeGenerator()
-
const
Properties
- annotationType → TypeIdentifier
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
Element2 element, ConstantReader annotation, BuildStep buildStep) → FutureOr< GenerateComponentResult> -
inherited
-
generateClass(
ClassElement2 element, ConstantReader annotation, BuildStep buildStep) → FutureOr< GenerateComponentResult> -
override
-
generateGetter(
GetterElement element, ConstantReader annotation, BuildStep buildStep) → FutureOr< GenerateComponentResult> -
override
-
generateType(
Element2 element, ConstantReader annotation, BuildStep buildStep) → FutureOr< GenerateComponentResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited