generator library

Classes

ComposedGenerator
GenerateComponentResult
GenerateOnAnnotation
GenerateOnAnnotationAnywhere
RecursiveAnnotationGenerator
Top2AnnotationGenerator
Generator on annotations of the top-two layers. Because the constructor and methods are usually at the second layer.
TopAnnotationGenerator
Generate only on the top layer, to avoid unnecessary recursive generation.

Extensions

MatchAnnotation on Annotatable
ResolveAnnotationType on ElementAnnotation

Exceptions / Errors

InvalidAnnotationPosition