GenerateAnnotatedClass mixin

Superclass constraints
Mixin applications

Properties

annotationType TypeIdentifier
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(Element2 element, ConstantReader annotation, BuildStep buildStep) FutureOr<GenerateComponentResult>
override
generateClass(ClassElement2 element, ConstantReader annotation, BuildStep buildStep) FutureOr<GenerateComponentResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited