RecursiveAnnotationGenerator class abstract
- Inheritance
-
- Object
- ComposedGenerator
- RecursiveAnnotationGenerator
- Mixed-in types
- Implementers
Constructors
- RecursiveAnnotationGenerator()
-
const
Properties
-
generators
→ Iterable<
GenerateOnAnnotationAnywhere> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
LibraryReader library, BuildStep buildStep) → Future< String?> -
Generates Dart code for an input Dart library.
inherited
-
generateComponents(
LibraryReader library, BuildStep buildStep) → Iterable< FutureOr< GenerateComponentResult> > -
override
-
generateOnElement(
Element2 element, BuildStep buildStep) → Iterable< FutureOr< GenerateComponentResult> > -
inherited
-
generateSingleLayer(
Element2 element, BuildStep buildStep) → Iterable< FutureOr< GenerateComponentResult> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited