Top2AnnotationGenerator class abstract
Generator on annotations of the top-two layers. Because the constructor and methods are usually at the second layer.
- Inheritance
-
- Object
- ComposedGenerator
- Top2AnnotationGenerator
- Mixed-in types
Constructors
- Top2AnnotationGenerator()
-
const
Properties
-
generators
→ Iterable<
GenerateOnAnnotationAnywhere> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
LibraryReader library, BuildStep buildStep) → Future< String?> -
Generates Dart code for an input Dart library.
inherited
-
generateComponents(
LibraryReader library, BuildStep buildStep) → Iterable< FutureOr< GenerateComponentResult> > -
override
-
generateOnElement(
Element2 element, BuildStep buildStep) → Iterable< FutureOr< GenerateComponentResult> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited