adaptiveCodeName property
String
get
adaptiveCodeName
Return into an adaptive valid Dart code name identifier.
When the first letter is uppercase, it will return the pascal case. Otherwise, it will return the camel case.
Implementation
String get adaptiveCodeName {
if (isEmpty) return '';
if (_upper) return pascalCase;
return camelCase;
}